@@ -5,7 +5,7 @@ into the rendered form (usually HTML) of that wikitext.
 Wikitext rendering is engaged when a tiddler is requested via a
 GET, when the negotiated MIME-type of the request is html,
 and when tiddler.type is either none or in the keys of the 
-dictionary associated with the tiddlyweb.config['wikitext_render_map'].
+dictionary associated with the tiddlyweb.config['wikitext.type_render_map'].
 
 When tiddler.type is none, the renderer named in
 tiddlyweb.config['wiktext_renderer'] is used. This is either a module
@@ -13,7 +13,7 @@ in the tiddlyweb.wikitext package, or a module on sys.path.
 
 When tiddler.type is something other than none, the renderer is
 determined by looking up the type in
-tiddlyweb.config['wikitext_render_map']. The found value is a 
+tiddlyweb.config['wikitext.type_render_map']. The found value is a 
 module of the same type described above.
 
 The renderer module has a function render.
@@ -54,7 +54,7 @@ def _determine_renderer(tiddler, environ):
     config = environ.get('tiddlyweb.config', {})
     try:
         if tiddler.type and tiddler.type != 'None':
-            return config['wikitext_render_map'][tiddler.type]
+            return config['wikitext.type_render_map'][tiddler.type]
     except KeyError:
         pass
-    return config.get('wikitext_renderer', DEFAULT_RENDERER)
+    return config.get('wikitext.default_renderer', DEFAULT_RENDERER)
